m4us.api — Message For You Sir! v0.2.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »
- API Documentation »

# `m4us.api`

Provides convenient access to all public objects.

This module imports all public objects from all the other modules in order to provide convenient access to them. This way you can use the following import line in your code:

    import m4us.api as m4us

By providing this convenience in a separate module (`m4us.api`), instead of in the package root (`m4us`), projects working under tight memory constraints can reduce the memory footprint of this project by instead directly importing only those modules they need.

See also

API Documentation and the various module documentation for details on the available objects in imported into this module.

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »
- API Documentation »